define(
//begin v1.x content
{
	"dateFormatItem-yMMMM": "MMMM y",
	"field-thu-narrow-relative+0": "jo. aceasta",
	"field-thu-narrow-relative+1": "jo. viitoare",
	"field-sun-narrow-relative+0": "du. aceasta",
	"field-sun-narrow-relative+1": "du. viitoare",
	"months-format-wide": [
		"ianuarie",
		"februarie",
		"martie",
		"aprilie",
		"mai",
		"iunie",
		"iulie",
		"august",
		"septembrie",
		"octombrie",
		"noiembrie",
		"decembrie"
	],
	"dayPeriods-standAlone-abbr-pm": "p.m.",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-fri-narrow-relative+0": "vi. aceasta",
	"field-fri-narrow-relative+1": "vi. viitoare",
	"eraNarrow": [
		"î.Hr.",
		"d.Hr."
	],
	"dateFormatItem-Hmv": "HH:mm v",
	"dateFormatItem-hmsv": "h:mm:ss a v",
	"dateFormatItem-yMMMd": "d MMM y",
	"dayPeriods-format-abbr-night1": "noaptea",
	"dayPeriods-format-narrow-evening1": "seara",
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"days-standAlone-wide": [
		"duminică",
		"luni",
		"marți",
		"miercuri",
		"joi",
		"vineri",
		"sâmbătă"
	],
	"dayPeriods-format-abbr-afternoon1": "după-amiaza",
	"dayPeriods-format-wide-evening1": "seara",
	"dateFormatItem-Ehm": "E h:mm a",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "mi. trecută",
	"dayPeriods-standAlone-wide-evening1": "seara",
	"field-minute-narrow-relative+0": "minutul acesta",
	"days-format-wide": [
		"duminică",
		"luni",
		"marți",
		"miercuri",
		"joi",
		"vineri",
		"sâmbătă"
	],
	"dateFormatItem-yMM": "MM.y",
	"field-month-short-relative+0": "luna aceasta",
	"field-month-short-relative+1": "luna viitoare",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dayPeriods-standAlone-narrow-evening1": "seara",
	"dayPeriods-standAlone-abbr-afternoon1": "după-amiaza",
	"field-thu-relative+0": "joia aceasta",
	"dayPeriods-standAlone-abbr-night1": "noaptea",
	"field-thu-relative+1": "joia viitoare",
	"dayPeriods-format-wide-am": "a.m.",
	"field-fri-relative+0": "vinerea aceasta",
	"field-fri-relative+1": "vinerea viitoare",
	"dateFormatItem-yMd": "dd.MM.y",
	"field-thu-narrow-relative+-1": "jo. trecută",
	"field-quarter-relative+0": "trimestrul acesta",
	"field-quarter-relative+1": "trimestrul viitor",
	"field-sun-short-relative+0": "dum. aceasta",
	"timeFormat-short": "HH:mm",
	"field-sun-short-relative+1": "dum. viitoare",
	"dateFormatItem-hms": "h:mm:ss a",
	"dayPeriods-format-narrow-afternoon1": "după-amiaza",
	"dateFormatItem-Md": "dd.MM",
	"dateFormatItem-Hmsv": "HH:mm:ss v",
	"dateFormatItem-hmv": "h:mm a v",
	"field-week-narrow": "săpt.",
	"field-hour-relative+0": "ora aceasta",
	"field-day-relative+-1": "ieri",
	"field-day-relative+-2": "alaltăieri",
	"field-mon-narrow-relative+-1": "lu. trecută",
	"field-minute-narrow": "m",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"field-thu-short-relative+0": "joia aceasta",
	"field-mon-relative+0": "lunea aceasta",
	"field-thu-short-relative+1": "joia viitoare",
	"field-mon-relative+1": "lunea viitoare",
	"field-day-narrow-relative+0": "azi",
	"field-era-short": "eră",
	"field-day-narrow-relative+1": "mâine",
	"field-sat-narrow-relative+0": "sâ. aceasta",
	"field-day-narrow-relative+2": "poimâine",
	"timeFormat-long": "HH:mm:ss z",
	"field-sat-narrow-relative+1": "sâ. viitoare",
	"field-week-narrow-relative+0": "săpt. aceasta",
	"field-week-narrow-relative+1": "săpt. viitoare",
	"field-hour-short-relative+0": "ora aceasta",
	"field-wed-narrow-relative+0": "mi. aceasta",
	"field-wed-narrow-relative+1": "mi. viitoare",
	"field-month": "lună",
	"months-standAlone-wide": [
		"ianuarie",
		"februarie",
		"martie",
		"aprilie",
		"mai",
		"iunie",
		"iulie",
		"august",
		"septembrie",
		"octombrie",
		"noiembrie",
		"decembrie"
	],
	"field-weekday-narrow": "ziua din săpt.",
	"dayPeriods-standAlone-narrow-afternoon1": "după-amiaza",
	"field-year-relative+0": "anul acesta",
	"field-year-relative+1": "anul viitor",
	"dayPeriods-format-abbr-evening1": "seara",
	"dayPeriods-format-abbr-noon": "amiază",
	"dayPeriods-format-narrow-midnight": "miezul nopții",
	"dayPeriods-format-wide-midnight": "la miezul nopții",
	"field-tue-relative+0": "marțea aceasta",
	"field-tue-relative+1": "marțea viitoare",
	"dayPeriods-standAlone-abbr-evening1": "seara",
	"field-minute-short-relative+0": "minutul acesta",
	"dateFormatItem-hm": "h:mm a",
	"dayPeriods-standAlone-wide-midnight": "la miezul nopții",
	"field-year-narrow": "an",
	"dayPeriods-standAlone-abbr-noon": "amiază",
	"field-tue-short-relative+0": "mar. aceasta",
	"dayPeriods-standAlone-narrow-midnight": "miezul nopții",
	"field-tue-short-relative+1": "mar. viitoare",
	"field-tue-narrow-relative+0": "ma. aceasta",
	"field-tue-narrow-relative+1": "ma. viitoare",
	"dateTimeFormat-full": "{1}, {0}",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-EBhm": "E h:mm B",
	"dateFormatItem-H": "HH",
	"field-wed-relative+0": "miercurea aceasta",
	"field-wed-relative+1": "miercurea viitoare",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "mie. aceasta",
	"field-fri-short-relative+0": "vin. aceasta",
	"field-wed-short-relative+1": "mie. viitoare",
	"field-fri-short-relative+1": "vin. viitoare",
	"field-weekOfMonth-short": "săpt. din lună",
	"field-quarter-short-relative+-1": "trim. trecut",
	"field-year-short-relative+-1": "anul trecut",
	"dateFormatItem-Bhm": "h:mm B",
	"dayPeriods-format-wide-night1": "noaptea",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-quarter-narrow-relative+-1": "trim. trecut",
	"dateFormatItem-d": "d",
	"dayPeriods-format-abbr-pm": "p.m.",
	"dateFormatItem-h": "h a",
	"quarters-standAlone-wide": [
		"trimestrul I",
		"trimestrul al II-lea",
		"trimestrul al III-lea",
		"trimestrul al IV-lea"
	],
	"field-weekOfMonth-narrow": "săpt. din lună",
	"dateFormatItem-y": "y",
	"field-minute-relative+0": "minutul acesta",
	"field-year-short-relative+0": "anul acesta",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-short-relative+1": "anul viitor",
	"field-weekday": "ziua din săptămână",
	"dayPeriods-format-narrow-pm": "p.m.",
	"field-tue-narrow-relative+-1": "ma. trecută",
	"dateFormatItem-yMEd": "E, dd.MM.y",
	"dayPeriods-standAlone-wide-night1": "noaptea",
	"field-year-narrow-relative+-1": "anul trecut",
	"field-sat-relative+-1": "sâmbăta trecută",
	"dayPeriods-format-abbr-midnight": "miezul nopții",
	"dayPeriods-format-narrow-morning1": "dimineața",
	"dayPeriods-format-wide-morning1": "dimineața",
	"dayPeriods-standAlone-abbr-midnight": "miezul nopții",
	"dayPeriods-standAlone-narrow-pm": "p.m.",
	"dayPeriods-standAlone-wide-morning1": "dimineața",
	"field-mon-narrow-relative+0": "lu. aceasta",
	"field-mon-narrow-relative+1": "lu. viitoare",
	"field-second": "secundă",
	"dateFormatItem-yMMMEd": "E, d MMM y",
	"field-year-relative+-1": "anul trecut",
	"field-weekdayOfMonth-short": "ziua săpt. din lună",
	"dateFormat-short": "dd.MM.y",
	"eraNames": [
		"înainte de Hristos",
		"după Hristos"
	],
	"field-second-short": "sec.",
	"field-thu-short-relative+-1": "joia trecută",
	"field-zone": "fus orar",
	"field-dayperiod-narrow": "a.m/p.m.",
	"field-sun-short-relative+-1": "dum. trecută",
	"dayPeriods-standAlone-narrow-morning1": "dimineața",
	"eraAbbr": [
		"î.Hr.",
		"d.Hr."
	],
	"field-week-short": "săpt.",
	"dayPeriods-standAlone-abbr-am": "a.m.",
	"dayPeriods-standAlone-wide-pm": "p.m.",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "azi",
	"field-day-relative+1": "mâine",
	"field-day-relative+2": "poimâine",
	"field-day-short-relative+0": "azi",
	"field-dayOfYear-short": "ziua din an",
	"field-day-short-relative+1": "mâine",
	"dateFormat-long": "d MMMM y",
	"field-day-short-relative+2": "poimâine",
	"field-sun-narrow-relative+-1": "du. trecută",
	"dayPeriods-format-wide-noon": "la amiază",
	"field-second-relative+0": "acum",
	"field-quarter-relative+-1": "trimestrul trecut",
	"dayPeriods-format-narrow-night1": "noaptea",
	"quarters-format-abbr": [
		"trim. I",
		"trim. II",
		"trim. III",
		"trim. IV"
	],
	"dayPeriods-standAlone-wide-noon": "la amiază",
	"dayPeriods-standAlone-narrow-night1": "noaptea",
	"field-week-relative+-1": "săptămâna trecută",
	"dayPeriods-format-abbr-morning1": "dimineața",
	"field-month-relative+-1": "luna trecută",
	"months-format-narrow": [
		"I",
		"F",
		"M",
		"A",
		"M",
		"I",
		"I",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year": "an",
	"field-era": "eră",
	"dayPeriods-standAlone-abbr-morning1": "dimineața",
	"days-standAlone-short": [
		"du.",
		"lu.",
		"ma.",
		"mi.",
		"joi",
		"vi.",
		"sâ."
	],
	"quarters-format-narrow": [
		"I",
		"II",
		"III",
		"IV"
	],
	"dateFormatItem-yQQQQ": "QQQQ y",
	"field-day-short-relative+-1": "ieri",
	"field-day-short-relative+-2": "alaltăieri",
	"dateFormatItem-GyMMM": "MMM y G",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-hour": "oră",
	"field-dayOfYear-narrow": "ziua din an",
	"field-second-narrow-relative+0": "acum",
	"field-quarter": "trimestru",
	"field-month-narrow-relative+0": "luna aceasta",
	"field-month-narrow-relative+1": "luna viitoare",
	"dateFormatItem-MMdd": "dd.MM",
	"field-day": "zi",
	"field-mon-relative+-1": "lunea trecută",
	"field-dayOfYear": "ziua din an",
	"dateFormat-medium": "d MMM y",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"dateFormatItem-MEd": "E, dd.MM",
	"field-tue-short-relative+-1": "mar. trecută",
	"field-year-short": "an",
	"field-month-short": "lună",
	"dateFormatItem-MMMEd": "E, d MMM",
	"dayPeriods-format-wide-afternoon1": "după-amiaza",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"ian.",
		"feb.",
		"mar.",
		"apr.",
		"mai",
		"iun.",
		"iul.",
		"aug.",
		"sept.",
		"oct.",
		"nov.",
		"dec."
	],
	"dayPeriods-format-abbr-am": "a.m.",
	"field-sat-relative+0": "sâmbăta aceasta",
	"field-sat-relative+1": "sâmbăta viitoare",
	"dayPeriods-format-wide-pm": "p.m.",
	"days-standAlone-abbr": [
		"dum.",
		"lun.",
		"mar.",
		"mie.",
		"joi",
		"vin.",
		"sâm."
	],
	"field-zone-short": "fus",
	"field-week-short-relative+0": "săpt. aceasta",
	"field-week-short-relative+1": "săpt. viitoare",
	"dayPeriods-standAlone-wide-afternoon1": "după-amiaza",
	"field-fri-short-relative+-1": "vin. trecută",
	"field-month-narrow": "lună",
	"dayPeriods-format-narrow-am": "a.m.",
	"field-month-narrow-relative+-1": "luna trecută",
	"days-format-abbr": [
		"dum.",
		"lun.",
		"mar.",
		"mie.",
		"joi",
		"vin.",
		"sâm."
	],
	"field-weekday-short": "ziua din săpt.",
	"field-day-narrow-relative+-1": "ieri",
	"field-day-narrow-relative+-2": "alaltăieri",
	"field-quarter-short": "trim.",
	"days-format-short": [
		"du.",
		"lu.",
		"ma.",
		"mi.",
		"joi",
		"vi.",
		"sâ."
	],
	"months-standAlone-narrow": [
		"I",
		"F",
		"M",
		"A",
		"M",
		"I",
		"I",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"dateFormatItem-EHm": "E HH:mm",
	"field-quarter-narrow": "trim.",
	"field-mon-short-relative+0": "lun. aceasta",
	"field-mon-short-relative+1": "lun. viitoare",
	"field-dayperiod-short": "a.m/p.m.",
	"dayPeriods-standAlone-narrow-am": "a.m.",
	"field-week-narrow-relative+-1": "săpt. trecută",
	"field-thu-relative+-1": "joia trecută",
	"field-fri-narrow-relative+-1": "vi. trecută",
	"field-mon-short-relative+-1": "lun. trecută",
	"timeFormat-medium": "HH:mm:ss",
	"field-quarter-short-relative+0": "trim. acesta",
	"field-quarter-short-relative+1": "trim. viitor",
	"dateFormatItem-Ed": "E d",
	"field-wed-relative+-1": "miercurea trecută",
	"field-weekOfMonth": "săptămâna din lună",
	"field-weekdayOfMonth-narrow": "ziua săpt. din lună",
	"dayPeriods-standAlone-wide-am": "a.m.",
	"dateFormatItem-yQQQ": "QQQ y",
	"field-fri-relative+-1": "vinerea trecută",
	"field-minute": "minut",
	"quarters-standAlone-narrow": [
		"I",
		"II",
		"III",
		"IV"
	],
	"field-second-short-relative+0": "acum",
	"quarters-format-wide": [
		"trimestrul I",
		"trimestrul al II-lea",
		"trimestrul al III-lea",
		"trimestrul al IV-lea"
	],
	"field-day-short": "zi",
	"field-dayperiod": "a.m/p.m.",
	"field-hour-short": "h",
	"months-standAlone-abbr": [
		"ian.",
		"feb.",
		"mar.",
		"apr.",
		"mai",
		"iun.",
		"iul.",
		"aug.",
		"sept.",
		"oct.",
		"nov.",
		"dec."
	],
	"field-month-relative+0": "luna aceasta",
	"field-second-narrow": "s",
	"field-month-relative+1": "luna viitoare",
	"dateFormat-full": "EEEE, d MMMM y",
	"field-era-narrow": "eră",
	"field-sat-short-relative+-1": "sâm. trecută",
	"dayPeriods-format-narrow-noon": "la amiază",
	"field-week-short-relative+-1": "săpt. trecută",
	"dateTimeFormat-long": "{1}, {0}",
	"dateFormatItem-yM": "MM.y",
	"field-sun-relative+-1": "duminica trecută",
	"field-wed-short-relative+-1": "mie. trecută",
	"field-weekdayOfMonth": "ziua săptămânii din lună",
	"field-quarter-narrow-relative+0": "trim. acesta",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"field-quarter-narrow-relative+1": "trim. viitor",
	"field-sat-short-relative+0": "sâm. aceasta",
	"field-hour-narrow": "h",
	"field-sat-short-relative+1": "sâm. viitoare",
	"field-year-narrow-relative+0": "anul acesta",
	"field-year-narrow-relative+1": "anul viitor",
	"dateFormatItem-Gy": "y G",
	"field-zone-narrow": "fus",
	"dayPeriods-standAlone-narrow-noon": "amiază",
	"field-tue-relative+-1": "marțea trecută",
	"field-minute-short": "min.",
	"dateFormatItem-yw": "'săptămâna' w 'din' Y",
	"dateFormatItem-Hm": "HH:mm",
	"field-week-relative+0": "săptămâna aceasta",
	"field-week-relative+1": "săptămâna viitoare",
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "duminica aceasta",
	"field-sun-relative+1": "duminica viitoare",
	"field-sat-narrow-relative+-1": "sâ. trecută",
	"quarters-standAlone-abbr": [
		"trim. I",
		"trim. II",
		"trim. III",
		"trim. IV"
	],
	"dateFormatItem-MMMMW": "'săptămâna' W 'din' MMMM",
	"field-month-short-relative+-1": "luna trecută",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-hour-narrow-relative+0": "ora aceasta",
	"field-week": "săptămână",
	"field-day-narrow": "zi"
}
//end v1.x content
);